@@ -1,6 +1,7 @@
 from typing import Dict
 
 from dagster import (
+    Array,
     AssetMaterialization,
     Bool,
     EventMetadataEntry,
@@ -114,7 +115,7 @@ def passthrough_flags_only(solid_config, additional_flags):
 @solid(
     description="A solid to invoke dbt run via CLI.",
     input_defs=[InputDefinition(name="start_after", dagster_type=Nothing)],
-    output_defs=[OutputDefinition(name="result", dagster_type=DbtCliOutput)],
+    output_defs=[OutputDefinition(name="dbt_output", dagster_type=DbtCliOutput)],
     config_schema={
         **CLI_CONFIG_SCHEMA,
         "threads": Field(
@@ -162,6 +163,15 @@ def passthrough_flags_only(solid_config, additional_flags):
                 "be yielded when the solid executes. Default: True"
             ),
         ),
+        "asset_key_prefix": Field(
+            config=Array(str),
+            is_required=False,
+            default_value=[],
+            description=(
+                "If provided and yield_materializations is True, these components will be used to "
+                "prefix the generated asset keys."
+            ),
+        ),
     },
     tags={"kind": "dbt"},
 )
@@ -185,7 +195,9 @@ def dbt_cli_run(context) -> DbtCliOutput:
     cli_output = DbtCliOutput.from_dict(cli_output_dict)
 
     if context.solid_config["yield_materializations"]:
-        for materialization in generate_materializations(cli_output):
+        for materialization in generate_materializations(
+            cli_output, asset_key_prefix=context.solid_config["asset_key_prefix"]
+        ):
             yield materialization
 
     yield AssetMaterialization(
@@ -194,13 +206,13 @@ def dbt_cli_run(context) -> DbtCliOutput:
         metadata_entries=[EventMetadataEntry.json(cli_output_dict, label="CLI Output")],
     )
 
-    yield Output(cli_output)
+    yield Output(cli_output, output_name="dbt_output")
 
 
 @solid(
     description="A solid to invoke dbt test via CLI.",
     input_defs=[InputDefinition(name="start_after", dagster_type=Nothing)],
-    output_defs=[OutputDefinition(name="result", dagster_type=DbtCliOutput)],
+    output_defs=[OutputDefinition(name="dbt_output", dagster_type=DbtCliOutput)],
     config_schema={
         **CLI_CONFIG_SCHEMA,
         "data": Field(
@@ -271,13 +283,13 @@ def dbt_cli_test(context) -> DbtCliOutput:
             metadata_entries=[EventMetadataEntry.json(cli_output, label="CLI Output")],
         )
 
-    yield Output(DbtCliOutput.from_dict(cli_output))
+    yield Output(DbtCliOutput.from_dict(cli_output), output_name="dbt_output")
 
 
 @solid(
     description="A solid to invoke dbt snapshot via CLI.",
     input_defs=[InputDefinition(name="start_after", dagster_type=Nothing)],
-    output_defs=[OutputDefinition(name="result", dagster_type=Dict)],
+    output_defs=[OutputDefinition(dagster_type=Dict)],
     config_schema={
         **CLI_CONFIG_SCHEMA,
         "threads": Field(
@@ -442,7 +454,11 @@ def dbt_cli_snapshot_freshness(context) -> Dict:
     output_defs=[OutputDefinition(name="result", dagster_type=Dict)],
     config_schema={
         **CLI_CONFIG_SCHEMA,
-        "parse-only": Field(config=bool, is_required=False, default_value=False,),
+        "parse-only": Field(
+            config=bool,
+            is_required=False,
+            default_value=False,
+        ),
         "threads": Field(
             config=Noneable(int),
             default_value=None,
